List of tutorials¶
2025-02-25
In FAIRmat tutorial 16, you'll learn how to use NOMAD to manage and organize your materials-science research data. Whether you are working with computational or experimental data, NOMAD's graphical user interface makes it easy to upload, share, explore, and analyze your data. We will also focus on using NOMAD to improve collaboration on your research projects and to ensure that your data align with the FAIR data principles.…Show less
2024-10-15
Demonstrates how to use the pynxtools package along with NOMAD to faciliate FAIR research data management for experimental data in materials science. Ellipsometry and Raman spectroscopy data are used as representative examples.
2024-07-09
Provides foundational knowledge for customizing NOMAD to fit the specific needs of your computational research project using the nomad-simulations schema plugin.
2024-05-14
Introduces NOMAD and NOMAD Oasis as essential tools for research data management (RDM), and demonstrates how to utilize these tools for managing experimental materials science data, with a particular focus on synthesis data.
2024-02-13
A practical session to go through a Jupyter notebook that demonstrates how to use NOMAD for managing custom data and file types. Based on a simple given dataset, we show how to model the data in a schema, do parsing and normalization, process data, access existing data with NOMAD's API for analysis, and how to add visualization to your data.…Show less
2023-10-24
Basic NOMAD usage with molecular dynamics simulations, custom workflows, python API
2023-06-13
Basic NOMAD usage for computational data, numerical precision filtering, custom workflows, knowledge-based XC functionals exploration
2023-04-25
Introduction the new plugin mechanism in NOMAD: how to develop and integrate their own Python schemas and parsers to a NOMAD Oasis.
2023-03-14
Using NOMAD as an ELN which enables the users to generate data following the FAIR principles.
2023-02-14
Uploading MD data, examining metadata, overview page, workflow visualizer, extracting MD data for trajectory analysis
2022-11-22
Follow research data lifecycle from planning and running an experiment to collecting and annotating data according to international community standards for searchability, and reuse.
2022-10-04
Navigate the materials space using the Encyclopedia GUI, and using the Encyclopedia API.
2022-05-10
How to get started with NOMAD Oasis and adapt it to your research.
2022-04-05
NOMAD AI-toolkit: query over the NOMAD Archive via the NOMAD API and basic notebooks for learning AI methods.
2022-03-08
ELN in FAIR data management, NOMAD ELN, and integrating other ELN tools with NOMAD.
2022-02-08
Basic NOMAD guide to prepare, upload, publish data, and reference them with a DOI.